INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbs.source', '1', 'oc-FR', 'oclc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbs.source', '2', 'oc-FR', 'Sistèma local');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbs.source', '3', 'oc-FR', 'Projècte Gutenberg');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cst.value', '1', 'oc-FR', 'Plan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cst.value', '2', 'oc-FR', 'Raiat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'identifier', 'oc-FR', 'Identificador');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqarad.description', '1', 'oc-FR', 'Identificador');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'keyword', 'oc-FR', 'Mot clau');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'title', 'oc-FR', 'Títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '5', 'oc-FR', 'Títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '14', 'oc-FR', 'Títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aba.name', 'title', 'oc-FR', 'Títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '1', 'oc-FR', 'Títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'author', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '51', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '4', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '13', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aba.name', 'author', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '2', 'oc-FR', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '1', 'oc-FR', 'Títol del periodic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '2', 'oc-FR', 'Abreviacion del títol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '18', 'oc-FR', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '2', 'oc-FR', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '11', 'oc-FR', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '5', 'oc-FR', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '3', 'oc-FR', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '19', 'oc-FR', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '6', 'oc-FR', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '15', 'oc-FR', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '6', 'oc-FR', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '4', 'oc-FR', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '21', 'oc-FR', 'ISMN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '27', 'oc-FR', 'ID intèrne');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '11', 'oc-FR', 'ID intèrne');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '38', 'oc-FR', 'Edicion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '14', 'oc-FR', 'Edicion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '40', 'oc-FR', 'Editor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '7', 'oc-FR', 'Editor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '16', 'oc-FR', 'Editor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '12', 'oc-FR', 'Editor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '44', 'oc-FR', 'Data de publicacion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '8', 'oc-FR', 'Data de publicacion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '17', 'oc-FR', 'Data de publicacion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '13', 'oc-FR', 'Data de publicacion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cit.name', '3', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aurt.label', '6', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '555', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '807', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '880', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '901', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '964', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '977', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '987', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1000', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1569', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1589', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1602', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1614', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1626', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1638', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1648', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1657', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1752', 'oc-FR', 'Autras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '1', 'oc-FR', '7_jorns_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '2', 'oc-FR', '7_jorns_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '3', 'oc-FR', '3_meses_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '4', 'oc-FR', '35_jorns_1_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '5', 'oc-FR', '3_meses_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '6', 'oc-FR', '35_jorns_1_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '7', 'oc-FR', '7_jorns_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '9', 'oc-FR', '7_jorns_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '10', 'oc-FR', '7_jorns_0_renovelament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '11', 'oc-FR', 'per defaut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crmf.name', '1', 'oc-FR', 'per defaut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crrf.name', '1', 'oc-FR', 'per defaut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crmf.name', '2', 'oc-FR', 'retard_maximum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crmf.name', '3', 'oc-FR', 'retard_maximum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crmf.name', '4', 'oc-FR', 'retard_maximum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crrf.name', '2', 'oc-FR', '10_cents_per_jorn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crrf.name', '3', 'oc-FR', '10_cents_per_jorn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crahp.name', '1', 'oc-FR', '3 meses');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crahp.name', '2', 'oc-FR', '6 meses');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '0', 'oc-FR', 'Disponible');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '3', 'oc-FR', 'Perdut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '4', 'oc-FR', 'Mancant');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '5', 'oc-FR', 'En tractament');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '6', 'oc-FR', 'En transit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '14', 'oc-FR', 'Damatjat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '15', 'oc-FR', 'Sus la laissa de las reservacions');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cnal.name', '1', 'oc-FR', 'Filtrat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cnal.name', '3', 'oc-FR', 'Accès interdich');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'en-US', 'oc-FR', 'Anglés (Estats Units)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'en-US', 'oc-FR', 'Anglés american');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'cs-CZ', 'oc-FR', 'Chèc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'cs-CZ', 'oc-FR', 'Chèc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '98', 'oc-FR', 'Chèc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'en-CA', 'oc-FR', 'Anglés (Canadà)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'en-CA', 'oc-FR', 'Anglés de Canadà');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'fi-FI', 'oc-FR', 'Finés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'fi-FI', 'oc-FR', 'Finés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '133', 'oc-FR', 'Finés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'hy-AM', 'oc-FR', 'Armèni');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'hy-AM', 'oc-FR', 'Armèni');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arm', 'oc-FR', 'Armèni');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'es-ES', 'oc-FR', 'Espanhòl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'es-ES', 'oc-FR', 'Espanhòl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '402', 'oc-FR', 'Espanhòl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'es-US', 'oc-FR', 'Anglés american');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'ru-RU', 'oc-FR', 'Rus');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'ru-RU', 'oc-FR', 'Rus');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '360', 'oc-FR', 'Rus');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czs.label', 'oclc', 'oc-FR', 'OCLC');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '3', 'oc-FR', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '12', 'oc-FR', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '5', 'oc-FR', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '18', 'oc-FR', 'Tipe d’element');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crad.description', 'item_type', 'oc-FR', 'Tipe d’element');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '7', 'oc-FR', 'Tipe d’element');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aout.opac_label', '1', 'oc-FR', 'Pertot');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aout.name', '2', 'oc-FR', 'Sistèma');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('csg.label', 'sys', 'oc-FR', 'Sistèma');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aout.name', '5', 'oc-FR', 'Bibliobús');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbt.name', '101', 'oc-FR', 'Divèrs');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '1', 'oc-FR', 'Utilizaires');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '2', 'oc-FR', 'Clients');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '3', 'oc-FR', 'Membres del personal');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '6', 'oc-FR', 'Aquisicions');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('csg.label', 'acq', 'oc-FR', 'Aquisicions');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '11', 'oc-FR', 'Periodic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('csg.label', 'serial', 'oc-FR', 'Periodic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('acpl.name', '1', 'oc-FR', 'Pilas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '4', 'oc-FR', 'Paginacion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '7', 'oc-FR', 'Prètz');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '9', 'oc-FR', 'Valor de NCT');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccpbt.label', 'misc', 'oc-FR', 'Divèrs');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccnbt.label', 'misc', 'oc-FR', 'Divèrs');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbrebt.label', 'misc', 'oc-FR', 'Divèrs');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'misc', 'oc-FR', 'Divèrs');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks', 'oc-FR', 'Amics');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks:circ.view', 'oc-FR', 'Renovelar de prèstes');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks:circ.renew', 'oc-FR', 'Renovelar de prèstes');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aar', 'oc-FR', 'Afar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'abk', 'oc-FR', 'Abkhaz');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ace', 'oc-FR', 'Achinés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ach', 'oc-FR', 'Acoli');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ada', 'oc-FR', 'Adangme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ady', 'oc-FR', 'Adygei');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'afr', 'oc-FR', 'Afrikaans');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '-ajm', 'oc-FR', 'Aljamía');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aka', 'oc-FR', 'Akan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'akk', 'oc-FR', 'Acadian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'alb', 'oc-FR', 'Albanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ale', 'oc-FR', 'Aleut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'alg', 'oc-FR', 'Algonquins (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'amh', 'oc-FR', 'Amaric');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ang', 'oc-FR', 'Anglosaxon (entre 450 e 1100)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'apa', 'oc-FR', 'Apachas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ara', 'oc-FR', 'Arabi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arc', 'oc-FR', 'Aramean');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arn', 'oc-FR', 'Mapuche');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arp', 'oc-FR', 'Arapaho');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'art', 'oc-FR', 'Artificialas (autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arw', 'oc-FR', 'Arawak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'asm', 'oc-FR', 'Assamés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ast', 'oc-FR', 'Bable');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aus', 'oc-FR', 'Lengas australianas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ava', 'oc-FR', 'Avaric');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ave', 'oc-FR', 'Avestan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'awa', 'oc-FR', 'Awadhi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aym', 'oc-FR', 'Aymara');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aze', 'oc-FR', 'Azèri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bad', 'oc-FR', 'Banda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bai', 'oc-FR', 'Bamilekés, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bak', 'oc-FR', 'Bashkir');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '40', 'oc-FR', 'Bambarà');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '41', 'oc-FR', 'Balinés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '42', 'oc-FR', 'Basc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '43', 'oc-FR', 'Basa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '44', 'oc-FR', 'Balticas (autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '45', 'oc-FR', 'Beja');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '46', 'oc-FR', 'Bielorus');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '47', 'oc-FR', 'Bembà');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '48', 'oc-FR', 'Bengali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '49', 'oc-FR', 'Berbèras (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '50', 'oc-FR', 'Bhojpuri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '51', 'oc-FR', 'Bihari');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '52', 'oc-FR', 'Bikol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '53', 'oc-FR', 'Edo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '54', 'oc-FR', 'Bislama');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '55', 'oc-FR', 'Siksika');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '56', 'oc-FR', 'Bantuas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '57', 'oc-FR', 'Bosniac');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '58', 'oc-FR', 'Braj');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '59', 'oc-FR', 'Breton');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '60', 'oc-FR', 'Batak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '61', 'oc-FR', 'Buriat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '62', 'oc-FR', 'Bugis');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '63', 'oc-FR', 'Bulgar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '64', 'oc-FR', 'Birman');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '65', 'oc-FR', 'Caddo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '66', 'oc-FR', 'Indianas d''America centrala, autras lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '67', 'oc-FR', 'Cmèr');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '222', 'oc-FR', 'Cmèr');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '68', 'oc-FR', 'Caribe');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '69', 'oc-FR', 'Catalan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '70', 'oc-FR', 'Caucasianas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '71', 'oc-FR', 'Cebuan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '72', 'oc-FR', 'Celticas (autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '73', 'oc-FR', 'Chamorro');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '74', 'oc-FR', 'Chibcha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '75', 'oc-FR', 'Chechèn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '76', 'oc-FR', 'Chagatai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '77', 'oc-FR', 'Chinés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '78', 'oc-FR', 'Truk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '440', 'oc-FR', 'Truk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '79', 'oc-FR', 'Mari');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '80', 'oc-FR', 'Chinook, girgon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '81', 'oc-FR', 'Choctaw');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '82', 'oc-FR', 'Chipewyan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '83', 'oc-FR', 'Cheroquí');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '84', 'oc-FR', 'Eslavon liturgic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '85', 'oc-FR', 'Chuvash');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '86', 'oc-FR', 'Cheyenne');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '87', 'oc-FR', 'Chamicas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '88', 'oc-FR', 'Còpte');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '89', 'oc-FR', 'Cornic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '90', 'oc-FR', 'Còrse');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '91', 'oc-FR', 'Lengas creòlas e pidgin, portugués (Autre)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '92', 'oc-FR', 'Lengas creòlas e pidgin, portugués (Autre)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '93', 'oc-FR', 'Lengas creòlas e pidgin, portugués (Autre)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '94', 'oc-FR', 'Cree');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '95', 'oc-FR', 'Tatar de Crimèa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '97', 'oc-FR', 'Coushiticas, autras lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '99', 'oc-FR', 'Dakòta');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '100', 'oc-FR', 'Danés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '101', 'oc-FR', 'Dargwa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '102', 'oc-FR', 'Dayak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '103', 'oc-FR', 'Delaware');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '104', 'oc-FR', 'Eslau');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '105', 'oc-FR', 'Dogrib');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '106', 'oc-FR', 'Dinka');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '107', 'oc-FR', 'Divehi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '108', 'oc-FR', 'Dogri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '109', 'oc-FR', 'Dravidian (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '110', 'oc-FR', 'Duala');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '111', 'oc-FR', 'Neerlandés mejan (env. 1050-1350)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '112', 'oc-FR', 'Neerlandés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '113', 'oc-FR', 'Dyula');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '114', 'oc-FR', 'Dzongkha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '115', 'oc-FR', 'Efik');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '116', 'oc-FR', 'Egipcian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '117', 'oc-FR', 'Ekajuk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '118', 'oc-FR', 'Elamit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '119', 'oc-FR', 'Anglés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '120', 'oc-FR', 'Anglés mejan (1100-1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '121', 'oc-FR', 'Esperanto');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '123', 'oc-FR', 'Esperanto');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '124', 'oc-FR', 'Estonian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '125', 'oc-FR', 'Etiopian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '152', 'oc-FR', 'Etiopian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '126', 'oc-FR', 'Ewe');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '127', 'oc-FR', 'Ewondo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '128', 'oc-FR', 'Fang');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '129', 'oc-FR', 'Feroés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '130', 'oc-FR', 'Feroés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '131', 'oc-FR', 'Fanti');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '132', 'oc-FR', 'Fijian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '134', 'oc-FR', 'Finoongrés (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '135', 'oc-FR', 'Fon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '136', 'oc-FR', 'Francés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '137', 'oc-FR', 'Frison');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '140', 'oc-FR', 'Frison');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '138', 'oc-FR', 'Francés mejan (1400-1600)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '141', 'oc-FR', 'Fula');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '142', 'oc-FR', 'Friolan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '143', 'oc-FR', 'Gã');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '144', 'oc-FR', 'Gaelic escocés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '154', 'oc-FR', 'Gaelic escocés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '145', 'oc-FR', 'Galician');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '156', 'oc-FR', 'Galician');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '146', 'oc-FR', 'Oromo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '328', 'oc-FR', 'Oromo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '147', 'oc-FR', 'Gayo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '148', 'oc-FR', 'Gbaya');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '149', 'oc-FR', 'Germanicas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '150', 'oc-FR', 'Georgian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '151', 'oc-FR', 'Alemand');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '153', 'oc-FR', 'Gilbertés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '155', 'oc-FR', 'Irlandés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '201', 'oc-FR', 'Irlandés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '157', 'oc-FR', 'Manx');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '275', 'oc-FR', 'Manx');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '158', 'oc-FR', 'Alemand, mejan naut (ca. 1050-1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '159', 'oc-FR', 'Alemand, vièlh naut (ca. 750-1050)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '160', 'oc-FR', 'Gondi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '161', 'oc-FR', 'Gorontalo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '162', 'oc-FR', 'Gotic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '163', 'oc-FR', 'Grebo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '164', 'oc-FR', 'Grèc, ancian (fins a 1453)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '165', 'oc-FR', 'Grèc modèrne (de 1453 a uèi)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '166', 'oc-FR', 'Guarani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '167', 'oc-FR', 'Guarani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '168', 'oc-FR', 'Gujarati');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '170', 'oc-FR', 'Haida');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '172', 'oc-FR', 'Hausa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '173', 'oc-FR', 'Hawaiian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '174', 'oc-FR', 'Ebrieu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '175', 'oc-FR', 'Herero');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '176', 'oc-FR', 'Hiligaynon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '177', 'oc-FR', 'Himachali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '178', 'oc-FR', 'Indi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '179', 'oc-FR', 'Itit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '180', 'oc-FR', 'Hmong');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '181', 'oc-FR', 'Hiri Motu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '182', 'oc-FR', 'Ongrés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '183', 'oc-FR', 'Hupa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '184', 'oc-FR', 'Iban');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '185', 'oc-FR', 'Igbo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '186', 'oc-FR', 'Islandés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '187', 'oc-FR', 'Ido');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '188', 'oc-FR', 'Yi de Sichuan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '189', 'oc-FR', 'Ijo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '190', 'oc-FR', 'Inuktitut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '191', 'oc-FR', 'Interlingue');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '192', 'oc-FR', 'Iloko');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '193', 'oc-FR', 'Interlingua (associacion per una lenga auxiliara internacionala)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '198', 'oc-FR', 'Interlingua (associacion per una lenga auxiliara internacionala)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '194', 'oc-FR', 'Indicas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '195', 'oc-FR', 'Indonesian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '196', 'oc-FR', 'Indoeuropèas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '197', 'oc-FR', 'Ingush');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '199', 'oc-FR', 'Inupiaq');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '200', 'oc-FR', 'Iranianas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '202', 'oc-FR', 'Iranianas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '203', 'oc-FR', 'Italian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '204', 'oc-FR', 'Javanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '205', 'oc-FR', 'Japonés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '206', 'oc-FR', 'Judeopèrse');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '207', 'oc-FR', 'Judeoarabi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '208', 'oc-FR', 'Kara-Kalpak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '209', 'oc-FR', 'Cabil');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '210', 'oc-FR', 'Kachin');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '211', 'oc-FR', 'Kalâtdlisut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '212', 'oc-FR', 'Kamba');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '213', 'oc-FR', 'Kannada');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '214', 'oc-FR', 'Karen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '215', 'oc-FR', 'Kashmiri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '216', 'oc-FR', 'Kanuri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '217', 'oc-FR', 'Kawi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '218', 'oc-FR', 'Cazak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '219', 'oc-FR', 'Kabardian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '220', 'oc-FR', 'Khasi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '221', 'oc-FR', 'Khoisan, autras lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '223', 'oc-FR', 'Khotanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '224', 'oc-FR', 'Kikuyu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '225', 'oc-FR', 'Kinyarwanda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '226', 'oc-FR', 'Quirguiz');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '227', 'oc-FR', 'Kimbundu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '228', 'oc-FR', 'Konkani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '229', 'oc-FR', 'Komi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '230', 'oc-FR', 'Kongo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '231', 'oc-FR', 'Corean');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '232', 'oc-FR', 'Kusaie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '239', 'oc-FR', 'Kusaie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '233', 'oc-FR', 'Kpelle');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '234', 'oc-FR', 'Kru');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '235', 'oc-FR', 'Kurukh');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '236', 'oc-FR', 'Kuanyama');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '237', 'oc-FR', 'Kumyk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '238', 'oc-FR', 'Curd');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '240', 'oc-FR', 'Kutenai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '241', 'oc-FR', 'Ladin');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '242', 'oc-FR', 'Lahnda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '243', 'oc-FR', 'Lamba');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '244', 'oc-FR', 'Occitan (aprèp 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '325', 'oc-FR', 'Occitan (aprèp 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '245', 'oc-FR', 'Lao');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '246', 'oc-FR', 'Lapon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '389', 'oc-FR', 'Lapon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '247', 'oc-FR', 'Latin');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '248', 'oc-FR', 'Leton');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '249', 'oc-FR', 'Lezgian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '250', 'oc-FR', 'Limburgués');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '251', 'oc-FR', 'Lingala');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '252', 'oc-FR', 'Lituanian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '253', 'oc-FR', 'Mongo-Nkundu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '254', 'oc-FR', 'Lozi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '256', 'oc-FR', 'Luba-Lulua');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '257', 'oc-FR', 'Luba-Katanga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '258', 'oc-FR', 'Ganda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '259', 'oc-FR', 'Luiseño');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '260', 'oc-FR', 'Lunda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '261', 'oc-FR', 'Luo (Kenya e Tanzania)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '262', 'oc-FR', 'Lushai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '263', 'oc-FR', 'Macedonian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '264', 'oc-FR', 'Madurés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '265', 'oc-FR', 'Magahi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '266', 'oc-FR', 'Marshallés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '267', 'oc-FR', 'Maithili');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '268', 'oc-FR', 'Macassar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '270', 'oc-FR', 'Mandingo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '271', 'oc-FR', 'Maòri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '272', 'oc-FR', 'Austronesianas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '273', 'oc-FR', 'Marathi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '274', 'oc-FR', 'Masaï');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '276', 'oc-FR', 'Malés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '277', 'oc-FR', 'Mandar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '278', 'oc-FR', 'Mende');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '279', 'oc-FR', 'Francés mejan (1400-1600)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '280', 'oc-FR', 'Micmac');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '281', 'oc-FR', 'Minangkabau');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '283', 'oc-FR', 'Môn-khmer, autras lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '284', 'oc-FR', 'Malgash');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '285', 'oc-FR', 'Malgash');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '286', 'oc-FR', 'Maltés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '287', 'oc-FR', 'Manchu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '288', 'oc-FR', 'Manipuri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '289', 'oc-FR', 'Manobo, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '290', 'oc-FR', 'Mohawk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '291', 'oc-FR', 'Moldau');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '292', 'oc-FR', 'Mongòl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '293', 'oc-FR', 'Mooré');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '294', 'oc-FR', 'Lengas multiplas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '295', 'oc-FR', 'Monda (Autre)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '296', 'oc-FR', 'Creek');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '297', 'oc-FR', 'Marwari');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '298', 'oc-FR', 'Maya, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '299', 'oc-FR', 'Nahuatl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '300', 'oc-FR', 'Indianas d''America del Sud (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '301', 'oc-FR', 'Italian napolitan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '302', 'oc-FR', 'Nauru');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '303', 'oc-FR', 'Navajo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '305', 'oc-FR', 'Ndebele (Zimbabwe)  ');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '306', 'oc-FR', 'Ndonga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '307', 'oc-FR', 'Bas alemand');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '308', 'oc-FR', 'Nepalés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '309', 'oc-FR', 'Newari');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '310', 'oc-FR', 'Nias');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '311', 'oc-FR', 'Nigerocongolesas, autras lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '312', 'oc-FR', 'Niuean');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '313', 'oc-FR', 'Norvegian (Nynorsk)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '314', 'oc-FR', 'Norvegian (Bokmål)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '315', 'oc-FR', 'Nogai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '317', 'oc-FR', 'Norvegian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '318', 'oc-FR', 'Sotho del Nòrd');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '319', 'oc-FR', 'Nubianas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '320', 'oc-FR', 'Nyanja');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '321', 'oc-FR', 'Nyamwezi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '322', 'oc-FR', 'Nyankole');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '323', 'oc-FR', 'Nyoro');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '324', 'oc-FR', 'Nzima');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '326', 'oc-FR', 'Ojibwa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '327', 'oc-FR', 'Oriya');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '329', 'oc-FR', 'Osage');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '330', 'oc-FR', 'Ossèt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '332', 'oc-FR', 'Otomanas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '333', 'oc-FR', 'Papó (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '334', 'oc-FR', 'Pangasinan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '335', 'oc-FR', 'Pahlavi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '336', 'oc-FR', 'Pampanga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '337', 'oc-FR', 'Panjabi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '338', 'oc-FR', 'Papiamento');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '339', 'oc-FR', 'Palauan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '341', 'oc-FR', 'Persan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '342', 'oc-FR', 'Filipina (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '343', 'oc-FR', 'Fenician');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '344', 'oc-FR', 'Pali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '345', 'oc-FR', 'Polonés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '346', 'oc-FR', 'Ponape');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '347', 'oc-FR', 'Portugués');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '348', 'oc-FR', 'Prakrit, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '349', 'oc-FR', 'Provençal (fins a 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '350', 'oc-FR', 'Pushto');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '351', 'oc-FR', 'Quíchoa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '352', 'oc-FR', 'Rajastanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '353', 'oc-FR', 'Rapanui');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '354', 'oc-FR', 'Rarotongan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '355', 'oc-FR', 'Romanicas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '356', 'oc-FR', 'Retoromanic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '357', 'oc-FR', 'Romani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '358', 'oc-FR', 'Romanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '359', 'oc-FR', 'Rundi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '361', 'oc-FR', 'Sandawe');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '363', 'oc-FR', 'Yakut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '364', 'oc-FR', 'Indianas d''America del Sud (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '365', 'oc-FR', 'Salishenas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '366', 'oc-FR', 'Aramean Samaritan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '367', 'oc-FR', 'Sanscrit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '368', 'oc-FR', 'Samoan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '392', 'oc-FR', 'Samoan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '369', 'oc-FR', 'Sasak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '370', 'oc-FR', 'Santali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '371', 'oc-FR', 'Sèrbe');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '372', 'oc-FR', 'Escocés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '373', 'oc-FR', 'Croat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '374', 'oc-FR', 'Selkup');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '375', 'oc-FR', 'Semiticas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '376', 'oc-FR', 'Vièlh irlandés (fins a 1100)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '377', 'oc-FR', 'Lengas dels signes');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '378', 'oc-FR', 'Shan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '379', 'oc-FR', 'Shona');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '394', 'oc-FR', 'Shona');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '380', 'oc-FR', 'Sidamo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '381', 'oc-FR', 'Singalés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '396', 'oc-FR', 'Singalés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '382', 'oc-FR', 'Papó (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '383', 'oc-FR', 'Sinotibetan (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '384', 'oc-FR', 'Eslavas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '385', 'oc-FR', 'Eslovac');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '386', 'oc-FR', 'Eslovèn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '387', 'oc-FR', 'Sami del Sud');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '388', 'oc-FR', 'Sami del Nòrd');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '390', 'oc-FR', 'Sami de Lule');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '393', 'oc-FR', 'Sami skolt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '395', 'oc-FR', 'Sindhi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '397', 'oc-FR', 'Soninke');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '398', 'oc-FR', 'Sogdian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '399', 'oc-FR', 'Somalian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '400', 'oc-FR', 'Songhai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '401', 'oc-FR', 'Sotho');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '406', 'oc-FR', 'Sotho');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '403', 'oc-FR', 'Sard');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '404', 'oc-FR', 'Serer');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '405', 'oc-FR', 'Nilosaharianas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '407', 'oc-FR', 'Swazi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '414', 'oc-FR', 'Swazi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '408', 'oc-FR', 'Sukuma');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '409', 'oc-FR', 'Sundanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '410', 'oc-FR', 'Susu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '411', 'oc-FR', 'Sumerian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '412', 'oc-FR', 'Swahili');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '413', 'oc-FR', 'Suedés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '415', 'oc-FR', 'Siriac');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '416', 'oc-FR', 'Tagalog');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '428', 'oc-FR', 'Tagalog');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '417', 'oc-FR', 'Tahitian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '418', 'oc-FR', 'Taï (autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '419', 'oc-FR', 'Tajik');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '427', 'oc-FR', 'Tajik');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '420', 'oc-FR', 'Tamol');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '421', 'oc-FR', 'Tatar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '422', 'oc-FR', 'Tatar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '423', 'oc-FR', 'Telugu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '424', 'oc-FR', 'Temne');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '425', 'oc-FR', 'Terena');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '426', 'oc-FR', 'Tetum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '429', 'oc-FR', 'Tai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '430', 'oc-FR', 'Tibetan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '431', 'oc-FR', 'Tigré');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '432', 'oc-FR', 'Tigrinya');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '433', 'oc-FR', 'Tiv');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '434', 'oc-FR', 'Tokelauan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '435', 'oc-FR', 'Tlingit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '436', 'oc-FR', 'Tamashek');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '437', 'oc-FR', 'Tònga (Nyasa)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '438', 'oc-FR', 'Tongan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '439', 'oc-FR', 'Tok Pisin');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '441', 'oc-FR', 'Tsimshian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '442', 'oc-FR', 'Tswana');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '444', 'oc-FR', 'Tswana');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '443', 'oc-FR', 'Tsònga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '445', 'oc-FR', 'Turcmèn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '446', 'oc-FR', 'Tumbuka');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '447', 'oc-FR', 'Tupi, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '448', 'oc-FR', 'Turc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '449', 'oc-FR', 'Altaïcas (Autras)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '450', 'oc-FR', 'Tuvaluan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '451', 'oc-FR', 'Twi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '452', 'oc-FR', 'Tuvinian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '453', 'oc-FR', 'Udmurt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '454', 'oc-FR', 'Ogaritic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '455', 'oc-FR', 'Oïgor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '456', 'oc-FR', 'Ucraïnian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '457', 'oc-FR', 'Umbundu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '458', 'oc-FR', 'Pas determinat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '459', 'oc-FR', 'Ordo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '460', 'oc-FR', 'Ozbèc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '461', 'oc-FR', 'Vai');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '462', 'oc-FR', 'Venda');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '463', 'oc-FR', 'Vietnamian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '464', 'oc-FR', 'Volapük');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '465', 'oc-FR', 'Votic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '466', 'oc-FR', 'Wakashanes, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '467', 'oc-FR', 'Walamo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '468', 'oc-FR', 'Waray');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '469', 'oc-FR', 'Washo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '470', 'oc-FR', 'Galés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '471', 'oc-FR', 'Sorabas, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '472', 'oc-FR', 'Valon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '473', 'oc-FR', 'Wolòf');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '474', 'oc-FR', 'Kalmyk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '475', 'oc-FR', 'Xhosa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '476', 'oc-FR', 'Yao (Africa)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '477', 'oc-FR', 'Yapés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '478', 'oc-FR', 'Yiddish');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '479', 'oc-FR', 'Yoruba');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '480', 'oc-FR', 'Yupik, lengas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '481', 'oc-FR', 'Zapotèc');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '482', 'oc-FR', 'Zenaga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '483', 'oc-FR', 'Zhuang');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '484', 'oc-FR', 'Zande');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '485', 'oc-FR', 'Zoló');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '486', 'oc-FR', 'Zuni');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '491', 'oc-FR', 'Adolescent');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '492', 'oc-FR', 'Adulte');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '494', 'oc-FR', 'General');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '497', 'oc-FR', 'Tèxte manuscrich');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '501', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '570', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '570', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '592', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '592', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '616', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '616', 'oc-FR', 'Trossa');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '502', 'oc-FR', 'Documents divèrses');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '503', 'oc-FR', 'Document cartografic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '513', 'oc-FR', 'Dramas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '515', 'oc-FR', 'Romans');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '517', 'oc-FR', 'Letras');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '520', 'oc-FR', 'Poesia');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '897', 'oc-FR', 'Poesia');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1565', 'oc-FR', 'Poesia');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1585', 'oc-FR', 'Poesia');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '521', 'oc-FR', 'Discorses');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '522', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '553', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '793', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '806', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '879', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '917', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '999', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1006', 'oc-FR', 'Desconegut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '523', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '903', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '524', 'oc-FR', 'Microficha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '904', 'oc-FR', 'Microficha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '525', 'oc-FR', 'Microficha opaca');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '905', 'oc-FR', 'Microficha opaca');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '527', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '565', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '565', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '589', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '589', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '611', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '611', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '908', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1792', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '529', 'oc-FR', 'Electronic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '712', 'oc-FR', 'Electronic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '712', 'oc-FR', 'Electronic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '911', 'oc-FR', 'Electronic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '531', 'oc-FR', 'Element de colleccions');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '532', 'oc-FR', 'Colleccion');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '536', 'oc-FR', 'Periodic');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '537', 'oc-FR', 'Beja');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '572', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '572', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '594', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '594', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '618', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '618', 'oc-FR', 'Microfilme');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '665', 'oc-FR', 'Editor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '689', 'oc-FR', 'Microficha opaca');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '695', 'oc-FR', 'Microficha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '885', 'oc-FR', 'Dramas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1553', 'oc-FR', 'Dramas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1573', 'oc-FR', 'Dramas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1007', 'oc-FR', 'Albanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1014', 'oc-FR', 'Azèri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1045', 'oc-FR', 'Bulgar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1058', 'oc-FR', 'Croat');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1074', 'oc-FR', 'Delaware');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1084', 'oc-FR', 'Estonian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1086', 'oc-FR', 'Etiopian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1098', 'oc-FR', 'Georgian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1112', 'oc-FR', 'Alemand');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1115', 'oc-FR', 'Hawaiian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1121', 'oc-FR', 'Islandés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1127', 'oc-FR', 'Indonesian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1151', 'oc-FR', 'Lituanian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1155', 'oc-FR', 'Leton');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1172', 'oc-FR', 'Mongòl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1197', 'oc-FR', 'Nepalés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1202', 'oc-FR', 'Nauru');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1232', 'oc-FR', 'Sèrbe');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1236', 'oc-FR', 'Romanés');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1254', 'oc-FR', 'Somalian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1264', 'oc-FR', 'Siriac');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1272', 'oc-FR', 'Tokelauan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1275', 'oc-FR', 'Tongan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1279', 'oc-FR', 'Tuvaluan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1308', 'oc-FR', 'Samoan');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1323', 'oc-FR', 'Macedonian');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1331', 'oc-FR', 'Eslovèn');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1787', 'oc-FR', 'Lengas dels signes');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1792', 'oc-FR', 'Braille');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aiit.name', 'TAX', 'oc-FR', 'Impòstes e taxas');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aiit.name', 'HND', 'oc-FR', 'Fraisses de manutencion');
